@@ -1,6 +1,5 @@
 import logging
 
-import django
 from django import forms
 from django.apps import apps
 from django.contrib.admin.widgets import AdminFileWidget, ForeignKeyRawIdWidget
@@ -14,9 +13,9 @@ logger = logging.getLogger(__name__)
 
 def thumbnail_url(image_path):
     thumbnail_options = {
-        'detail': True,
-        'upscale': True,
-        'size': settings.IMAGE_CROPPING_THUMB_SIZE,
+        "detail": True,
+        "upscale": True,
+        "size": settings.IMAGE_CROPPING_THUMB_SIZE,
     }
     return get_backend().get_thumbnail_url(image_path, thumbnail_options)
 
@@ -44,13 +43,13 @@ def get_attrs(image, name):
             width = image.width
             height = image.height
         return {
-            'class': "crop-thumb",
-            'data-thumbnail-url': thumbnail_url(image),
-            'data-field-name': name,
-            'data-org-width': width,
-            'data-org-height': height,
-            'data-max-width': width,
-            'data-max-height': height,
+            "class": "crop-thumb",
+            "data-thumbnail-url": thumbnail_url(image),
+            "data-field-name": name,
+            "data-org-width": width,
+            "data-org-height": height,
+            "data-max-width": width,
+            "data-max-height": height,
         }
     except (ValueError, AttributeError, IOError):
         # can't create thumbnail from image
@@ -58,7 +57,6 @@ def get_attrs(image, name):
 
 
 class CropWidget:
-
     def _media(self):
         js = [
             "image_cropping/js/dist/image_cropping.min.js",
@@ -97,7 +95,7 @@ class HiddenImageCropWidget(ImageCropWidget):
         # we need to hide it the whole field by JS because the admin
         # doesn't yet support hidden fields:
         # https://code.djangoproject.com/ticket/11277
-        attrs['data-hide-field'] = True
+        attrs["data-hide-field"] = True
         render_args = [name, value, attrs]
         if renderer:
             render_args.append(renderer)
@@ -106,7 +104,7 @@ class HiddenImageCropWidget(ImageCropWidget):
 
 class CropForeignKeyWidget(ForeignKeyRawIdWidget, CropWidget):
     def __init__(self, *args, **kwargs):
-        self.field_name = kwargs.pop('field_name')
+        self.field_name = kwargs.pop("field_name")
         super().__init__(*args, **kwargs)
 
     def render(self, name, value, attrs=None, renderer=None):
@@ -125,11 +123,15 @@ class CropForeignKeyWidget(ForeignKeyRawIdWidget, CropWidget):
                 if image:
                     attrs.update(get_attrs(image, name))
             except (ObjectDoesNotExist, LookupError):
-                logger.error("Can't find object: %s.%s with primary key %s "
-                             "for cropping." % (app_name, model_name, value))
+                logger.error(
+                    "Can't find object: %s.%s with primary key %s "
+                    "for cropping." % (app_name, model_name, value)
+                )
             except AttributeError:
-                logger.error("Object %s.%s doesn't have an attribute named '%s'." % (
-                    app_name, model_name, self.field_name))
+                logger.error(
+                    "Object %s.%s doesn't have an attribute named '%s'."
+                    % (app_name, model_name, self.field_name)
+                )
 
         render_args = [name, value, attrs]
         if renderer:
